# criteria-pattern-core

Library classes for the criteria-pattern package.

Provides the [Criterion](src/Criterion.js) class which can be extended to satisfy the
interface `criterias` expects and the [Result](src/Result.js) class that each `Criterion#call` must
return.

## Installation

`npm install --save criterias-basics`

## Usage

```javascript
import * as basics from 'criteria-pattern-basics';

```

This library provides the following Criterion:

### Boolean
Casts its value to a boolean.

```javascript
basics.boolean();
```

### Number
Casts a value to a number.
```javascript
basics.number();
```
### String
Casts a value to a string.
```javascript
basics.string();
```

### Array
Splits a string into an array or wraps a value in one. You can pass a character to
treat as the sperator.
```javascript
basics.array(',')
```

### Equals
Checks if the value is equal to the value supplied.
```javascript
basics.equals(44).satisfy(33); // returns Failure
```

### TypeOf
Checks if the value satisfies the type specified.
```javascript
basics.typeOf('string').satisfy('a decent string'); // returns 'a decent string';
```

### Match
Test the value against a regular expression.
```javascript
basics.match(^/[\w]/).satisfy('@'); //returns Failure;
```

### Range
Tests whether the value falls within a specific range.
```javascript
basics.range(3, 14).satisfy(12); //returns 12; 
```
